import isBlob from './isBlob';



const MSSave = 'msSaveBlob' in navigator;



export function fileSavingSupported() {
  return 'Blob' in window && (MSSave || 'download' in HTMLAnchorElement.prototype);
}


/**
 * Create file with given content and trigger download
 * @param  {String|Blob} content - The content of the file
 * @param  {String} name - Name of the file
 * @param  {String} [type='text/plain; charset=utf-8'] - Content type of the file
 */
export default function saveFile(content, name, type = 'text/plain; charset=utf-8') {
  if (!fileSavingSupported()) { return; }

  if (!isBlob(content)) {
    content = new Blob([`${content}`], { type });
  }

  if (MSSave) {
    navigator.msSaveBlob(content);
  } else {
    const a = document.createElement('a');
    a.download = true;
    a.href = URL.createObjectURL(content);
    a.click();
  }
}
