import isNumber from 'vanillajs-helpers/isNumber';

import isDOMChildNode from './isDOMChildNode';



/**
 * Scroll an element or the window to the given position
 *
 * @function scrollTo
 * @param {HTMLElement|window} [elm = window] - The element to find the scrolling position from
 * @param {Number} x - How much to scroll the horisontal scroll by
 * @param {Number} y - How much to scroll the vertical scroll by
 * @return {HTMLElement|window} The scrolling element (if no element was given Window is returned)
 */
export default function scrollTo(elm, x, y) {
  if (isNumber(elm)) { [elm, x, y] = [window, elm, x]; }
  if (!isNumber(x)) { return elm; }

  if (!isDOMChildNode(elm)) { elm = window; }
  if (!isNumber(y)) { y = elm.scrollY || elm.scrollTop; }

  x = Math.max(x, 0);
  y = Math.max(y, 0);

  if (elm.scrollTo) {
    elm.scrollTo(x, y);
  } else {
    elm.scrollLeft = x;
    elm.scrollTop = y;
  }

  return elm;
}
