const div = document.createElement('div');



// TODO: Use native CSS.supports


export function supportsProp(prop, value) {
  if (typeof div.style[prop] === 'undefined') { return false; }
  if (!value) { return true; }

  div.style[prop] = value;
  return div.style[prop] === value;
}



/**
 * Detect wether or not the given css property (and/or) value is supported by
 * the current browser
 * @param  {String} prop    - Property to test
 * @param  {String} value   - Value to test with the property
 * @return {Boolean|Object} - Returns object if property is supported with prefix,
 *                            otherwise a boolean is returned
 */
export default function supportsCSS(prop, value) {
  // Property (+ value) is supported natively as is
  if (supportsProp(prop, value)) { return true; }

  // Testing vendorPrefixed values
  let vendorPrefixed = false;

  ['-moz-', '-webkit-', '-ms-', '-khtml-', '-o-']
    .some((prefix) => {
      const vendorPrefixedProp = prefix + prop;
      const vendorPrefixedValue = prefix + value;

      // Prefixed prop
      if (supportsProp(vendorPrefixedProp, value)) {
        vendorPrefixed = { prop: vendorPrefixedProp, value, prefix };

        // Prefixed value
      } else if (supportsProp(prop, vendorPrefixedValue)) {
        vendorPrefixed = { prop, value: vendorPrefixedValue, prefix };

        // Prefixed prop and value
      } else if (supportsProp(vendorPrefixedProp, vendorPrefixedValue)) {
        vendorPrefixed = { prop: vendorPrefixedProp, value: vendorPrefixedValue, prefix };
      }

      // Found it?
      return !!vendorPrefixed;
    });

  return vendorPrefixed;
}
